@@ -118,11 +118,8 @@ $(function() {
     //Fire when wrapper is resized
     $(".wrapper").resize(function() {
         _fix();
-        fix_sidebar();
     });
 
-    //Fix the fixed layout sidebar scroll bug
-    fix_sidebar();
 
     /*
      * We are gonna initialize all checkbox and radio inputs to
